"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const StorageError_1 = tslib_1.__importDefault(require("./StorageError"));
/**
 * A factory class maintains all Azure Storage Blob service errors.
 *
 * @export
 * @class StorageErrorFactory
 */
class StorageErrorFactory {
    static getContainerNotFound(contextID) {
        return new StorageError_1.default(404, "ContainerNotFound", "The specified container does not exist.", contextID);
    }
    static getContainerAlreadyExists(contextID) {
        return new StorageError_1.default(409, "ContainerAlreadyExists", "The specified container already exists.", contextID);
    }
    static getBlobNotFound(contextID) {
        return new StorageError_1.default(404, "BlobNotFound", "The specified blob does not exist.", contextID);
    }
    static getInvalidQueryParameterValue(contextID) {
        return new StorageError_1.default(400, "InvalidQueryParameterValue", `Value for one of the query parameters specified in the request URI is invalid.`, contextID);
    }
    static getInvalidOperation(contextID, message = "") {
        return new StorageError_1.default(400, "InvalidOperation", message, contextID);
    }
    static getInvalidPageRange(contextID) {
        return new StorageError_1.default(416, "Requested Range Not Satisfiable", "The page range specified is invalid.", contextID);
    }
    static getInvalidLeaseDuration(contextID) {
        return new StorageError_1.default(400, "InvalidHeaderValue", "The value for one of the HTTP headers is not in the correct format.", contextID);
    }
    static getInvalidLeaseBreakPeriod(contextID) {
        return new StorageError_1.default(400, "InvalidHeaderValue", "The value for one of the HTTP headers is not in the correct format.", contextID);
    }
    static getInvalidId(contextID) {
        return new StorageError_1.default(400, "InvalidHeaderValue", "The value for one of the HTTP headers is not in the correct format.", contextID);
    }
    static getLeaseAlreadyPresent(contextID) {
        return new StorageError_1.default(409, "LeaseAlreadyPresent", "There is already a lease present.", contextID);
    }
    static getContainerLeaseNotPresentWithLeaseOperation(contextID) {
        return new StorageError_1.default(409, "LeaseNotPresentWithLeaseOperation", "There is currently no lease on the container.", contextID);
    }
    static getContainerLeaseIdMismatchWithLeaseOperation(contextID) {
        return new StorageError_1.default(409, "LeaseIdMismatchWithLeaseOperation", "The lease ID specified did not match the lease ID for the container.", contextID);
    }
    static getLeaseIsBrokenAndCannotBeRenewed(contextID) {
        return new StorageError_1.default(409, "LeaseIsBrokenAndCannotBeRenewed", "The lease ID matched, but the lease has been broken explicitly and cannot be renewed.", contextID);
    }
    static getLeaseIsBreakingAndCannotBeChanged(contextID) {
        return new StorageError_1.default(409, "LeaseIsBreakingAndCannotBeChanged", "The lease ID matched, but the lease is currently in breaking state and cannot be changed.", contextID);
    }
    static getContainerLeaseIdMissing(contextID) {
        return new StorageError_1.default(412, "LeaseIdMissing", "There is currently a lease on the container and no lease ID was specified in the request.", contextID);
    }
    static getContainerLeaseIdMismatchWithContainerOperation(contextID) {
        return new StorageError_1.default(412, "LeaseIdMismatchWithContainerOperation", "The lease ID specified did not match the lease ID for the container.", contextID);
    }
    static getContainerLeaseLost(contextID) {
        return new StorageError_1.default(412, "LeaseLost", "A lease ID was specified, but the lease for the container has expired.", contextID);
    }
    static getBlobLeaseIdMismatchWithLeaseOperation(contextID) {
        return new StorageError_1.default(409, "LeaseIdMismatchWithLeaseOperation", "The lease ID specified did not match the lease ID for the blob.", contextID);
    }
    static getBlobLeaseNotPresentWithLeaseOperation(contextID) {
        return new StorageError_1.default(409, "LeaseNotPresentWithLeaseOperation", "There is currently no lease on the blob.", contextID);
    }
    // The error code/message need check with server
    static getBlobSnapshotsPresent(contextID) {
        return new StorageError_1.default(400, "SnapshotsPresent", "This operation is not permitted because the blob is snapshot.", contextID);
    }
    static getBlobLeaseIdMissing(contextID) {
        return new StorageError_1.default(412, "LeaseIdMissing", "There is currently a lease on the blob and no lease ID was specified in the request.", contextID);
    }
    static getBlobLeaseIdMismatchWithBlobOperation(contextID) {
        return new StorageError_1.default(412, "LeaseIdMismatchWithBlobOperation ", "The lease ID specified did not match the lease ID for the blob.", contextID);
    }
    static getBlobLeaseLost(contextID) {
        return new StorageError_1.default(412, "LeaseLost ", "A lease ID was specified, but the lease for the blob has expired.", contextID);
    }
    static getAuthorizationFailure(contextID) {
        return new StorageError_1.default(403, "AuthorizationFailure", 
        // tslint:disable-next-line:max-line-length
        "Server failed to authenticate the request. Make sure the value of the Authorization header is formed correctly including the signature.", contextID);
    }
    static getBlobInvalidBlobType(contextID) {
        return new StorageError_1.default(409, "InvalidBlobType", "The blob type is invalid for this operation.", contextID);
    }
    static getBlobSnapshotsPresent_hassnapshot(contextID) {
        return new StorageError_1.default(409, "SnapshotsPresent", "This operation is not permitted because the blob has snapshots.", contextID);
    }
    static getBlobCannotChangeToLowerTier(contextID) {
        return new StorageError_1.default(409, "CannotChangeToLowerTier", "A higher blob tier has already been explicitly set.", contextID);
    }
    static getBlobBlobTierInadequateForContentLength(contextID) {
        return new StorageError_1.default(409, "BlobTierInadequateForContentLength", "Specified blob tier size limit cannot be less than content length.", contextID);
    }
    static getAuthorizationSourceIPMismatch(contextID) {
        return new StorageError_1.default(403, "AuthorizationSourceIPMismatch", "This request is not authorized to perform this operation using this source IP {SourceIP}.", contextID);
    }
    static getAuthorizationProtocolMismatch(contextID) {
        return new StorageError_1.default(403, "AuthorizationProtocolMismatch", "This request is not authorized to perform this operation using this protocol.", contextID);
    }
    static getAuthorizationPermissionMismatch(contextID) {
        return new StorageError_1.default(403, "AuthorizationPermissionMismatch", "This request is not authorized to perform this operation using this permission.", contextID);
    }
    static getAuthorizationServiceMismatch(contextID) {
        return new StorageError_1.default(403, "AuthorizationServiceMismatch", "This request is not authorized to perform this operation using this service.", contextID);
    }
    static getAuthorizationResourceTypeMismatch(contextID) {
        return new StorageError_1.default(403, "AuthorizationResourceTypeMismatch", "This request is not authorized to perform this operation using this resource type.", contextID);
    }
    static getFeatureVersionMismatch(contextID) {
        return new StorageError_1.default(409, "FeatureVersionMismatch", "Stored access policy contains a permission that is not supported by this version.", contextID);
    }
    static getCopyIdMismatch(contextID) {
        return new StorageError_1.default(409, "CopyIdMismatch", "The specified copy ID did not match the copy ID for the pending copy operation.", contextID);
    }
    static getNoPendingCopyOperation(contextID) {
        return new StorageError_1.default(409, "NoPendingCopyOperation", "There is currently no pending copy operation.", contextID);
    }
    static getSnapshotsPresent(contextID) {
        return new StorageError_1.default(409, "SnapshotsPresent", "This operation is not permitted while the blob has snapshots.", contextID);
    }
}
exports.default = StorageErrorFactory;
//# sourceMappingURL=StorageErrorFactory.js.map