"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Async iterator to enumerate all extent IDs.
 *
 * @export
 * @class LokiAllExtentsAsyncIterator
 * @implements {AsyncIterator<string[]>}
 */
class LokiAllExtentsAsyncIterator {
    constructor(blobDataStore) {
        this.blobDataStore = blobDataStore;
        this.unit = 1000;
        this.done = false;
    }
    async next() {
        if (this.done) {
            return { done: true, value: [] };
        }
        const [extents, nextMarker] = await this.blobDataStore.listExtents(undefined, undefined, this.unit, this.marker);
        this.marker = nextMarker;
        if (nextMarker === undefined) {
            this.done = true;
        }
        return {
            done: false,
            value: extents.map(val => val.id)
        };
    }
}
exports.default = LokiAllExtentsAsyncIterator;
//# sourceMappingURL=LokiAllExtentsAsyncIterator.js.map