"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const args_1 = tslib_1.__importDefault(require("args"));
const constants_1 = require("../blob/utils/constants");
args_1.default
    .option(["", "blobHost"], "Optional. Customize listening address", constants_1.DEFAULT_SERVER_HOST_NAME)
    .option(["", "blobPort"], "Optional. Customize listening port", constants_1.DEFAULT_SERVER_LISTENING_PORT)
    .option("location", "Optional. Use an existing folder as workspace path, default is current working directory", process.cwd())
    .option("silent", "Optional. Disable access log displayed in console")
    .option("debug", "Optional. Enable debug log by providing a valid local file path as log destination");
args_1.default.config.name = "azurite";
class Environment {
    constructor() {
        this.flags = args_1.default.parse(process.argv);
    }
    get blobHost() {
        return this.flags.blobHost;
    }
    get blobPort() {
        return this.flags.blobPort;
    }
    get location() {
        return this.flags.location || process.cwd();
    }
    get silent() {
        if (this.flags.silent !== undefined) {
            return true;
        }
        return false;
    }
    get debug() {
        if (typeof this.flags.debug === "string") {
            // Enable debug log to file
            return this.flags.debug;
        }
        if (this.flags.debug === true) {
            throw RangeError(`Must provide a debug log file path for parameter -d or --debug`);
        }
        // By default disable debug log
    }
}
exports.default = Environment;
//# sourceMappingURL=Environment.js.map